Skip to contents

Vasicek's conditional default probability: $$PD_{PIT} = \Phi\left(\frac{\Phi^{-1}(PD_{TTC}) - \sqrt{\rho}\, z}{\sqrt{1-\rho}}\right),$$ and its inverse for to = "ttc". A positive z is a benign state (lower PIT PD), a negative one a stressed state.

Usage

scr_pd_pit_ttc(pd, z, rho, to = c("pit", "ttc"))

Arguments

pd

Numeric PDs in (0, 1).

z

Systematic factor (standard normal scale).

rho

Asset correlation in (0, 1).

to

"pit" (input is TTC) or "ttc" (input is PIT).

Value

A numeric vector of the length of pd.

References

Vasicek, O. (2002). The distribution of loan portfolio value. Risk, 15(12), 160-162.

See also

scr_pd_stress(), the same bridge with the systematic factor given as a quantile q rather than a value of z.

Other irb-pd: predict.scr_grades(), predict.scr_pd(), scr_calibrate(), scr_grades(), scr_master_scale(), scr_migration(), scr_moc(), scr_pd(), scr_pd_validate()

Examples

scr_pd_pit_ttc(c(0.01, 0.05), z = -2, rho = 0.15)
#> [1] 0.04617685 0.17260368
scr_pd_pit_ttc(scr_pd_pit_ttc(0.02, z = -1, rho = 0.1), z = -1, rho = 0.1, to = "ttc")
#> [1] 0.02