Apply an alignment to raw scores
Arguments
- object
An object from
scr_align().- raw
Raw scores on the same scale used in the fit.
- type
"score"(default) returns points;"prob"returns the calibrated event probability implied by the alignment.- ...
Ignored.
See also
Other production:
scr_apply(),
scr_export(),
scr_monitor(),
scr_monitoring_plan(),
scr_reasons(),
scr_sql()
Examples
set.seed(3)
y <- stats::rbinom(2000, 1, 0.15)
raw <- stats::qlogis(0.15) + 1.3 * y + stats::rnorm(2000)
al <- scr_align(raw, y)
head(predict(al, raw))
#> [1] 545.4062 603.0933 597.0212 642.2758 539.8784 586.7383
head(predict(al, raw, type = "prob"))
#> [1] 0.117124721 0.017649730 0.021694049 0.004599538 0.138432936 0.030697183